<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ar" sourcelanguage="en">
  <context>
    <name>StartPage</name>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="42"/>
      <source>Start</source>
      <translation>البدء</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="43"/>
      <source>Documents</source>
      <translation>المستندات</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="44"/>
      <source>Help</source>
      <translation>مساعدة</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="45"/>
      <source>Activity</source>
      <translation>النشاط</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="46"/>
      <source>Recent files</source>
      <translation>الملفات الأخيرة</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="47"/>
      <source>Tip</source>
      <translation>فائدة</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="48"/>
      <source>Adjust the number of recent files to be shown here in menu Edit -&gt; Preferences -&gt; General -&gt; Size of recent file list</source>
      <translation>اضبط عدد الملفات الحديثة التي ستظهر هنا من قائمة ”تحرير -&gt; التفضيلات -&gt; عام -&gt; مقاس قائمة الملفات الحديثة“</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="49"/>
      <source>Examples</source>
      <translation>أمثلة</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="50"/>
      <source>General documentation</source>
      <translation>التوثيق العام</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="51"/>
      <source>User hub</source>
      <translation>مَجمع المستخدمين</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="52"/>
      <source>This section contains documentation useful for FreeCAD users in general: a list of all the workbenches, detailed instructions on how to install and use the FreeCAD application, tutorials, and all you need to get started.</source>
      <translation>يحتوي هذا القسم على توثيقات مفيدة لمستخدم فري‌كاد بشكل عام: قائمة من طاولات العمل، وإرشادات مفصّلة لطريقة تثبيت واستخدام تطبيق فري‌كاد ودروسه وكل ما تحتاج لتبدأ العمل.</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="53"/>
      <source>Power users hub</source>
      <translation>مركز المستخدمين المتقدمين</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="54"/>
      <source>This section gathers documentation for advanced users and people interested in writing python scripts. You will also find there a repository of macros, instructions on how to install and use them, and more information about customizing FreeCAD to your specific needs.</source>
      <translation>يجمع هذا القسم الوثائق للمستخدمين المتقدمين والأشخاص المهتمين بكتابة نصوص بايثون. سوف تجد هناك أيضًا مستودعًا لماكرو ، تعليمات حول كيفية تثبيته واستخدامه، والمزيد من المعلومات حول تخصيص FreeCAD لاحتياجاتك الخاصة.</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="55"/>
      <source>Developers hub</source>
      <translation>مَجمع المطوّرين</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="55"/>
      <source>This section contains material for developers: How to compile FreeCAD yourself, how the FreeCAD source code is structured + how to navigate in it, how to develop new workbenches and/or embed FreeCAD in your own application.</source>
      <translation>يحتوي هذا القسم على مواد للمطورين: كيفية تجميع FreeCAD بنفسك، كيف يتم هيكلة شفرة المصدر لـ FreeCAD + كيفية التنقل فيها، وكيفية تطوير طاولات عمل جديدة و/أو تضمين FreeCAD في التطبيق الخاص بك.</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="57"/>
      <source>Manual</source>
      <translation>الدليل</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="58"/>
      <source>The FreeCAD manual is another, more linear way to present the information contained in this wiki. It is made to be read like a book, and will gently introduce you to many other pages from the hubs above. &lt;a href="https://www.gitbook.com/book/yorikvanhavre/a-freecad-manual/details"&gt;e-book versions&lt;/a&gt; are also available.</source>
      <translation>دليل FreeCAD هو طريقة أخرى أكثر خطيّة لعرض المعلومات الموجودة في هذا الويكي. تم إعداده لكي يقرأ ككتاب، وسوف يعرفك بلطف على العديد من الصفحات الأخرى من المحاور المذكورة أعلاه. &lt;a href="https://www.gitbook.com/book/yorikvanhavre/a-freecad-manual/details"&gt;الإصدارات الإلكترونية&lt;/a&gt; متوفرة أيضا.</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="59"/>
      <source>Workbenches documentation</source>
      <translation>توثيق طاولات العمل</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="60"/>
      <source>These are the help pages of all the workbenches currently installed on this computer.</source>
      <translation>هذه هي صفحات المساعدة لكل طاولات العمل المثبّتة في هذا الحاسوب حاليًا.</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="61"/>
      <source>Getting help from the community</source>
      <translation>التماس المساعدة من المجتمع</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="62"/>
      <source>The &lt;a href="http://forum.freecadweb.org"&gt;FreeCAD forum&lt;/a&gt; is a great place to get help from other FreeCAD users and developers. The forum has many sections for different types of issues and discussion subjects. If in doubt, post in the more general &lt;a href="https://forum.freecadweb.org/viewforum.php?f=3"&gt;Help on using FreeCAD&lt;/a&gt; section.</source>
      <translation>إنّ &lt;a href="http://forum.freecadweb.org"&gt;منتدى فري‌كاد&lt;/a&gt; لهو مكان رائع لتلتمس يد المساعدة من مستخدمي ومطوّري فري‌كاد الآخرين. في المنتدى عدّة أقسام لمختلف المشاكل والمواضيع النقاشية. إن كتت محتارًا أين تضع موضوعك، فضعه في قسم &lt;a href="https://forum.freecadweb.org/viewforum.php?f=3"&gt;Help on using FreeCAD&lt;/a&gt; العام.</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="63"/>
      <source>If it is the first time you are posting on the forum, be sure to &lt;a href="https://forum.freecadweb.org/viewtopic.php?f=3&amp;t=2264"&gt;read the guidelines&lt;/a&gt; first!</source>
      <translation>إن كانت هذه أول مرة لك تنشر فيها شيئًا في المنتدى فلا تنسَ &lt;a href="https://forum.freecadweb.org/viewtopic.php?f=3&amp;t=2264"&gt;قراءة القواعد&lt;/a&gt; بادئ ذي بدء!</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="64"/>
      <source>FreeCAD also maintains a public &lt;a href="https://www.freecadweb.org/tracker"&gt;bug tracker&lt;/a&gt; where anybody can submit bugs and propose new features. To avoid causing extra work and give the best chances to see your bug solved, make sure you read the &lt;a href="https://forum.freecadweb.org/viewtopic.php?f=3&amp;t=5236"&gt;bug submission guide&lt;/a&gt; before posting.</source>
      <translation>تحافظ FreeCAD أيضًا على &lt;a href="https://www.freecadweb.org/tracker"&gt;تعقب الأخطاء&lt;/a&gt; بشكل عام حيث يمكن لأي شخص تقديم الأخطاء واقتراح ميزات جديدة. لتجنب التسبب في عمل إضافي وإعطاء أفضل الفرص لرؤية الخلل الخاص بك، تأكد من قراءة &lt;a href="https://forum.freecadweb.org/viewtopic.php?f=3&amp;t=5236"&gt;دليل إرسال الأخطاء&lt;/a&gt; قبل النشر.</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="65"/>
      <source>Available addons</source>
      <translation>الإضافات المتوفّرة</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="66"/>
      <source>Below is a list of available extra workbenches that can be added to your FreeCAD installation. Browse and install them from menu Tools -&gt; Addons manager. You can learn more about any of them by clicking the links below.</source>
      <translation>تجد أدناه قائمة من طاولات العمل الإضافية التي يمكنك إضافتها إلى فري‌كاد لديك. تصفّحها وثبّت ما تريد من قائمة ”أدوات -&gt; مدير الإضافات“. يمكنك الاطلاع أكثر عما تفعل كل إضافة بنقر الروابط أدناه.</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="67"/>
      <source>If not bundled with your FreeCAD version, install the FreeCAD documentation package to get documentation hubs, workbench help and individual command documentation without an internet connection.</source>
      <translation>إذا لم يتم الجمع مع إصدار FreeCAD الخاص بك، قم بتثبيت حزمة وثائق FreeCAD للحصول على محاور التوثيق، مساعدة طاولة العمل ووثائق الأوامر الفردية بدون اتصال بالإنترنت.</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="68"/>
      <source>Cannot fetch information from GitHub. &lt;a href="EnableDownload.py"&gt;Authorize FreeCAD to access the internet&lt;/a&gt; and reload the Start page.</source>
      <translation>تعذّر جلب المعلومات من غِت‌هَب. &lt;a href="EnableDownload.py"&gt;اسمح بأن يدخل فري‌كاد الإنترنت&lt;/a&gt; وأعِد تحميل صفحة البداية.</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="69"/>
      <source>Recent commits</source>
      <translation>أحدث الإيداعات</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="70"/>
      <source>Below are the latest changes added to the &lt;a href="http://github.com/FreeCAD/FreeCAD/"&gt;FreeCAD source code&lt;/a&gt;. These changes might not reflect yet in the FreeCAD version that you are currently running. Check the &lt;a href="https://www.freecadweb.org/wiki/Downloads"&gt;available options&lt;/a&gt; if you wish to obtain a development version.</source>
      <translation>تجد أدناه أحدث الإعدادات التي أُضيفت إلى &lt;a href="http://github.com/FreeCAD/FreeCAD/"&gt;الكود المصدري لِـفري‌كاد&lt;/a&gt;. لربما لا تكون هذه الإيداعات موجودة بعد في إصدارة فري‌كاد التي تستخدمها حاليًا. طالع &lt;a href="https://www.freecadweb.org/wiki/Downloads"&gt;الخيارات المتوفّرة&lt;/a&gt; إن أردت استخدام إصدارة تطويرية.</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="71"/>
      <source>See all commits on github</source>
      <translation>طالع كل الإيداعات في غِت‌هَب</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="71"/>
      <source>You can configure a custom folder to display here in menu Edit -&gt; Preferences -&gt; Start -&gt; Show additional folder</source>
      <translation>يمكنك تكوين مجلد مخصص للعرض هنا في القائمة تحرير -&gt; تفضيلات -&gt; بدء -&gt; إظهار مجلد إضافي</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="73"/>
      <source>version</source>
      <translation>إصدار</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="74"/>
      <source>build</source>
      <translation>بنية</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="75"/>
      <source>Create new...</source>
      <translation>أنشِئ جديدًا...</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="76"/>
      <source>Unknown</source>
      <translation>مجهول</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="77"/>
      <source>Forum</source>
      <translation>المنتدى</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="78"/>
      <source>The latest posts on the &lt;a href="https://forum.freecadweb.org"&gt;FreeCAD forum&lt;/a&gt;:</source>
      <translation>أحدث المواضيع في &lt;a href="https://forum.freecadweb.org"&gt;منتدى فري‌كاد&lt;/a&gt;:</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="79"/>
      <source>To open any of the links above in your desktop browser, Right-click -&gt; Open in external browser</source>
      <translation>لتفتح أيًا من الروابط أعلاه في متصفّح الإنترنت لديك على سطح المكتب، انقر باليمين واختر ”افتح في المتصفّح الخارجي“</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="80"/>
      <source>Creation date</source>
      <translation>تاريخ الإنشاء</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="81"/>
      <source>Last modification</source>
      <translation>آخر تعديل</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="82"/>
      <source>Notes</source>
      <translation>الملاحظات</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="82"/>
      <source>Open start page preferences</source>
      <translation>فتح تفضيلات صفحة البداية</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Command.cpp" line="58"/>
      <location filename="../../Workbench.cpp" line="65"/>
      <source>Start page</source>
      <translation>صفحة البداية</translation>
    </message>
  </context>
  <context>
    <name>CmdStartPage</name>
    <message>
      <location filename="../../Command.cpp" line="44"/>
      <source>Start</source>
      <translation>البدء</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="45"/>
      <source>Start Page</source>
      <translation>صفحة البداية</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="46"/>
      <source>Displays the start page in a browser view</source>
      <translation>عرض صفحة البداية في عرض المتصفح</translation>
    </message>
  </context>
  <context>
    <name>DlgStartPreferences</name>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="14"/>
      <source>Start page options</source>
      <translation>اعدادات صفحة البداية</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="20"/>
      <source>Start page template</source>
      <translation>قالب صفحة البداية</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="26"/>
      <source>An optional HTML template that will be used instead of the default start page.</source>
      <translation>قالب HTML اختياري سيتم استخدامه بدلاً من صفحة البداية الافتراضية.</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="42"/>
      <source>Contents</source>
      <translation>المحتويات</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="48"/>
      <source>Show forum</source>
      <translation>إظهار المنتدى</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="55"/>
      <source>Show examples folder contents</source>
      <translation>إظهار محتويات مجلد الأمثلة</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="62"/>
      <source>Show additional folder</source>
      <translation>إظهار مجلد إضافي</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="69"/>
      <source>If you want the examples to show on the first page</source>
      <translation>إذا كنت تريد أن تظهر الأمثلة في الصفحة الأولى</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="91"/>
      <source>If this is checked, the latest posts from the FreeCAD forum will be displayed on the Activity tab</source>
      <translation>إذا تم تحديد هذا الخيار، سيتم عرض أحدث المشاركات من منتدى FreeCAD على لسان النشاط</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="110"/>
      <source>An optional custom folder to be displayed at the bottom of the first page</source>
      <translation>مجلد مخصص اختياري ليتم عرضه في أسفل الصفحة الأولى</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="126"/>
      <source>Show notepad</source>
      <translation>إظهار المفكرة</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="133"/>
      <source>Shows a notepad next to the file thumbnails, where you can keep notes across FreeCAD sessions</source>
      <translation>يظهر المفكرة بجانب الصور المصغرة للملف، حيث يمكنك الاحتفاظ بالملاحظات عبر جلسات FreeCAD</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="155"/>
      <source>Fonts and colors</source>
      <translation>الخطوط والألوان</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="167"/>
      <source>The background of the main start page area</source>
      <translation>خلفية منطقة صفحة البداية الرئيسية</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="187"/>
      <source>Background color</source>
      <translation>لون الخلفية</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="199"/>
      <source>in FreeCAD</source>
      <translation>في FreeCAD</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="218"/>
      <source>In external browser</source>
      <translation>في متصفح خارجي</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="236"/>
      <source>Background color gradient down</source>
      <translation>تدرج لون الخلفية لأسفل</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="249"/>
      <source>The color of the version text</source>
      <translation>لون نص الإصدار</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="269"/>
      <source>Link color</source>
      <translation>لون الرابط</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="276"/>
      <source>An optional image to display as background</source>
      <translation>صورة اختيارية لعرضها كخلفية</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="289"/>
      <source>If this is checked, if a style sheet is specified in General preferences, it will be used and override the colors below</source>
      <translation>إذا تم تحديد هذا الخيار، إذا تم تحديد ورقة نمط في التفضيلات العامة، سيتم استخدامه وتجاوز الألوان أدناه</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="308"/>
      <source>Page background color</source>
      <translation>لون خلفية الصفحة</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="321"/>
      <source>The color of the text on the main pages</source>
      <translation>لون النص في الصفحات الرئيسية</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="341"/>
      <source>Background image</source>
      <translation>صورة الخلفية</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="348"/>
      <source>Page text color</source>
      <translation>لون نص الصفحة</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="361"/>
      <source>The color of the links</source>
      <translation>لون الروابط</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="387"/>
      <source>The background color of the boxes inside the pages</source>
      <translation>لون خلفية المربعات داخل الصفحات</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="407"/>
      <source>Box background color</source>
      <translation>لون خلفية المربع</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="420"/>
      <source>The background color behind the panels</source>
      <translation>لون الخلفية وراء اللوحات</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="449"/>
      <source>The down gradient for the background color (currently unsupported)</source>
      <translation>التدريج السفلي للون الخلفية (غير مدعوم حاليا)</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="472"/>
      <source>Open links</source>
      <translation>فتح الروابط</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="479"/>
      <source>Background text color</source>
      <translation>لون نص الخلفية</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="486"/>
      <source>Use FreeCAD style sheet</source>
      <translation>استخدام ورقة نمط FreeCAD</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="493"/>
      <source>Font family</source>
      <translation>قائمة الخطوط</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="502"/>
      <source>The font family to use on the start page. Can be a font name or a comma-separated series of fallback fonts</source>
      <translation>عائلة الخط لاستخدامها في صفحة البداية. يمكن أن يكون اسم خط أو سلسلة مفصولة بفواصل من خطوط التراجع</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="508"/>
      <source>Arial,Helvetica,sans</source>
      <translation>Arial, Helvetica,sans</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="521"/>
      <source>The base font size to use for all texts of the Start page</source>
      <translation>حجم الخط الأساسي لاستخدامه لجميع النصوص في صفحة البداية</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="524"/>
      <source>px</source>
      <translation type="unfinished">px</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="542"/>
      <source>Use gradient for New File icon</source>
      <translation>استخدام لون تدريجي لرمز الملف الجديد</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="568"/>
      <source>Options</source>
      <translation>الخيارات</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="577"/>
      <source>Should the start page be closed after loading?</source>
      <translation>هل ينبغي إغلاق صفحة البداية بعد التحميل؟</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="596"/>
      <source>Switch workbench after loading</source>
      <translation>تبديل طاولة العمل بعد التحميل</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="603"/>
      <source>Close start page after loading</source>
      <translation>إغلاق صفحة البداية بعد التحميل</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="610"/>
      <source>Close &amp; switch on file open</source>
      <translation>إغلاق و التبديل عند فتح الملف</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="617"/>
      <source>If FreeCAD is started by opening a file, apply the two settings above</source>
      <translation>إذا تم تشغيل FreeCAD بفتح ملف، قم بتطبيق الإعدادين أعلاه</translation>
    </message>
  </context>
</TS>
